Page 130 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 130

Home

    Hurley, sent several foreign service officers home
    because of their pro-Communist activities. When they
    were promoted over his head, Ambassador Hurley
    resigned in disgust. He later testified that:

    The record of General Stilwell in China is irrevocably
    coupled in history with the conspiracy to overthrow the
    Nationalist Government of China, and to set up in its
    place a Communist regime — and all this movement was
    part of and cannot be separated from, the Communist
    cell or apparatus that existed at the time in the
    Government in Washington."

    President Truman sent his Secretary of State, George
    Marshall, to China to pressure Chiang to form a coalition
    government with Mao's Communists. Marshall even

    trroa oo nm

    guerrillas. This plan was blocked by Congress. Marshall
    later placed an arms embargo on military aid to the
    Nationalists. Although Congress appropriated $125
    million for military aid to Chiang, the Truman
    administration ran such interference that only a small
    portion of it ever reached Chiang and it proved to be too
    little and too late. Chiang wrote in his diary that
    Marshall, "continues to try to accommodate the
    Communists in every possible way and force us to make
    concessions. He doesn't seem to care whether China

    survives or perishes. This indeed is a most painful
    . . 14
    situation."

    125

    Babylon's War Against God

    wanted to send U. S. officers to train Communist